function [] = updateWorkspaceOffsetsTable()
%UPDATEOFFSETSTABLE Summary of this function goes here
%   Detailed explanation goes here

global artoaWorkspace;

%% Check if track parameter already exist
if ~artoa.data.hasMember(artoaWorkspace, {'editOffsets'})
    return;
end

%% Prepare required variables
soundsources = artoa.controller.getSoundsourcesWithAppliedToa();

%% Initialize if not available
if ~artoa.data.hasMember(artoaWorkspace, {'editOffsets', 'offsets'})
    % initialize sound source offsets
    artoaWorkspace.editOffsets.offsets = ...
        artoa.offsets.generateOffsetTable(artoaWorkspace.float, soundsources);
end

workspaceOffsets = artoaWorkspace.editOffsets.offsets;

%% Add every soundsource
fnames = fieldnames(soundsources);
for i = 1:length(fnames)
    workspaceOffsets = artoa.offsets.addSoundsource( ...
        workspaceOffsets, ...
        soundsources.(fnames{i}) ...
    );
    if ~isnan(workspaceOffsets{fnames{i}, 'DateStart'}) ...
            && ~isnan(workspaceOffsets{fnames{i}, 'OffsetStart'}) ...
            && ~isnan(workspaceOffsets{fnames{i}, 'DateEnd'}) ...
            && ~isnan(workspaceOffsets{fnames{i}, 'OffsetEnd'})
        workspaceOffsets{fnames{i}, 'Drift'} = artoa.drift.byStartEndOffset( ...
            workspaceOffsets{fnames{i}, 'DateEnd'} - workspaceOffsets{fnames{i}, 'DateStart'}, ...
            workspaceOffsets{fnames{i}, 'OffsetStart'}, ...
            workspaceOffsets{fnames{i}, 'OffsetEnd'} ...
        );
    else
        workspaceOffsets{fnames{i}, 'Drift'} = NaN;
    end
end

%% Check if there are soundsources that should be removed
rowNames = workspaceOffsets.Properties.RowNames;
for i = 1:length(rowNames)
    if any(strcmp(rowNames{i}, fnames)) || strcmp(rowNames{i}, 'Float')
        continue;
    end
    workspaceOffsets = artoa.offsets.removeSoundsource( ...
        workspaceOffsets, ...
        rowNames{i} ...
    );
end

artoaWorkspace.editOffsets.offsets = workspaceOffsets;