function [] = plot()
%PLOT Plots or updates the pressure points.
%   If the plot already exists and is valid, the points only get updated.
%   Otherwise the plot will be initialized
%

global artoaGui artoaWorkspace;

%% Get all required values
% create color vector
c = repmat([1 1 0], length(artoaWorkspace.rafosDate), 1);
c(artoaWorkspace.statusPressure == 1, :) = ...
    repmat([1 1 1], length(c(artoaWorkspace.statusPressure == 1, 1)), 1);
c(artoaWorkspace.statusPressure == 2, :) = ...
    repmat([1 0 0], length(c(artoaWorkspace.statusPressure == 2, 1)), 1);

if artoaWorkspace.hideDeletedDataPoints
    x = artoaWorkspace.rafosDate(artoaWorkspace.statusPressure ~= 2);
    y = artoaWorkspace.pressure(artoaWorkspace.statusPressure ~= 2);
    c = c(artoaWorkspace.statusPressure ~= 2, :);
else
    x = artoaWorkspace.rafosDate;
    y = artoaWorkspace.pressure;
end

%% If the plot exists, just update the values

if isfield(artoaGui.editPressure, 'scatterPressure') ...
        && isvalid(artoaGui.editPressure.scatterPressure)
    artoaGui.editPressure.scatterPressure.XData = x;
    artoaGui.editPressure.scatterPressure.YData = y;
    artoaGui.editPressure.scatterPressure.CData = c;
    return
end

hold on;

% get all points that are not deleted
artoaGui.editPressure.scatterPressure = scatter( ...
    artoaGui.figures.editPressure.CurrentAxes, ...
    x, ...
    y, ...
    [], ...
    c, ... %'.', 'MarkerSize', 10 ...
    'filled' ...
);

grid on;

% set background color
set(artoaGui.figures.editPressure.CurrentAxes, 'Color', [.3 .3 .3], 'XColor', 'blue', 'YColor', 'blue');

% set plot title
titleVal = [ ...
    'Project: ' artoaWorkspace.float.projectname ...
    ' FloatId: ' num2str(artoaWorkspace.float.floatname) ...
    ' Cycle: ' num2str(artoaWorkspace.float.cycle(1)) ...
    ' - Pressure' ...
];
titleHandle = title(artoaGui.figures.editPressure.CurrentAxes, titleVal, 'FontSize', 10);
set(titleHandle, 'Color', 'blue');

% set x and y label
xlabel(artoaGui.figures.editPressure.CurrentAxes, 'Message Date', 'FontSize', 10);
ylabel(artoaGui.figures.editPressure.CurrentAxes, 'Pressure [dBar]', 'FontSize', 10);

hold off;



end

