function [] = pickPolygon()
%PICKPOLYGON Lets the user pick a polygon in the plot.
%   During selection, a line is being plotted that shows the selected
%   points by the user.
%   The polygon can be stopped by using the right mouse button. If
%   finished, the selected points are being calculated and stored in the
%   artoaWorkspace variable.

global artoaGui artoaWorkspace;

%% Check if polygon is already selected

if artoa.controller.edit.dataPointsSelected(artoaWorkspace.editTemperature)
    if strcmp(questdlg('Reset current line and pick a new one?', 'Confirmation', 'Yes', 'Cancel', 'Cancel'), 'Cancel')
        return;
    end
    % reset the line and all required fields
    [artoaGui.editTemperature, artoaWorkspace.editTemperature] = artoa.controller.edit.clearSelection(artoaGui.editTemperature, artoaWorkspace.editTemperature);
end

%% Select polygon by mouse
x = [];
y = [];

% draw the line that will be extended on every click
artoaGui.editTemperature.userSelection = line( ...
    NaN, NaN, 'Color', [1 1 1], 'LineStyle', '-' ...
);

[dx, dy, button] = ginput(1);
while button == 1
    % get boundaries
    bound = artoaGui.figures.editTemperature.CurrentAxes.XLim;
    dx = artoa.data.adjustToBoundaries(dx, bound(1), bound(2));
    bound = artoaGui.figures.editTemperature.CurrentAxes.YLim;
    dy = artoa.data.adjustToBoundaries(dy, bound(1), bound(2));
    % add values to array
    x = [x; dx];
    y = [y; dy];
    if length(x) == 1
        continue;
    end
    % update the line
    set(artoaGui.editTemperature.userSelection, 'XData', x, 'YData', y);
    [dx, dy, button] = ginput(1);
end

% close the poligon by adding the first value as the last one
if length(x) > 3 % a polygon can only be closed if there are more than three values
    x = [x; x(1)];
    y = [y; y(1)];
else
    [artoaGui.editTemperature, artoaWorkspace.editTemperature] = artoa.controller.edit.clearSelection(artoaGui.editTemperature, artoaWorkspace.editTemperature);
    return;
end
% update the line
set(artoaGui.editTemperature.userSelection, 'XData', x, 'YData', y);

% store the selected points in the workspace for editing
artoaWorkspace.editTemperature.userSelection = inpolygon( ...
    artoaWorkspace.rafosDate, ...
    artoaWorkspace.temperature, ...
    x, ...
    y ...
);



end

