function [] = plot()
%PLOT Plots or updates the temperature points.
%   If the plot already exists and is valid, the points only get updated.
%   Otherwise the plot will be initialized
%

global artoaGui artoaWorkspace;

%% Get all required values
% create color vector
c = repmat([1 1 0], length(artoaWorkspace.rafosDate), 1);
c(artoaWorkspace.statusTemperature == 1, :) = ...
    repmat([1 1 1], length(c(artoaWorkspace.statusTemperature == 1, 1)), 1);
c(artoaWorkspace.statusTemperature == 2, :) = ...
    repmat([1 0 0], length(c(artoaWorkspace.statusTemperature == 2, 1)), 1);

if artoaWorkspace.hideDeletedDataPoints
    x = artoaWorkspace.rafosDate(artoaWorkspace.statusTemperature ~= 2);
    y = artoaWorkspace.temperature(artoaWorkspace.statusTemperature ~= 2);
    c = c(artoaWorkspace.statusTemperature ~= 2, :);
else
    x = artoaWorkspace.rafosDate;
    y = artoaWorkspace.temperature;
end

%% If the plot exists, just update the values

if isfield(artoaGui.editTemperature, 'scatterTemperature') ...
        && isvalid(artoaGui.editTemperature.scatterTemperature)
    artoaGui.editTemperature.scatterTemperature.XData = x;
    artoaGui.editTemperature.scatterTemperature.YData = y;
    artoaGui.editTemperature.scatterTemperature.CData = c;
    return
end

hold on;

% get all points that are not deleted
artoaGui.editTemperature.scatterTemperature = scatter( ...
    artoaGui.figures.editTemperature.CurrentAxes, ...
    x, ...
    y, ...
    [], ...
    c, ... %'.', 'MarkerSize', 10 ...
    'filled' ...
);

grid on;

% set background color
set(artoaGui.figures.editTemperature.CurrentAxes, 'Color', [.3 .3 .3], 'XColor', 'blue', 'YColor', 'blue');

% set plot title
titleVal = [ ...
    'Project: ' artoaWorkspace.float.projectname ...
    ' FloatId: ' num2str(artoaWorkspace.float.floatname) ...
    ' Cycle: ' num2str(artoaWorkspace.float.cycle(1)) ...
    ' - Temperature' ...
];
titleHandle = title(artoaGui.figures.editTemperature.CurrentAxes, titleVal, 'FontSize', 10);
set(titleHandle, 'Color', 'blue');

% set x and y label
xlabel(artoaGui.figures.editTemperature.CurrentAxes, 'Message Date', 'FontSize', 10);
ylabel(artoaGui.figures.editTemperature.CurrentAxes, 'Temperature [C]', 'FontSize', 10);

hold off;



end

