function [] = applySoundSourceToAllVisible()
%APPLYSTATUSTOALLVISIBLE Applies the given status code to the visible points.
%   Applies the selected status to the workspace variable.
%

global artoaWorkspace artoaGui;

%% Check if soundsources are loaded
if ~artoa.controller.soundSourcesLoaded()
    warndlg('You need to load a soundsource file first!', 'No sound sources loaded');
    return;
end

%% Get all visible points
x_boundary = artoaGui.editTimeOfArrival.axesScatterTimeOfArrival.XLim;
y_boundary = artoaGui.editTimeOfArrival.axesScatterTimeOfArrival.YLim;

selection = inpolygon( ...
    artoaWorkspace.toaData.toaDate, ...
    artoaWorkspace.toaData.toa, ...
    [x_boundary(1) x_boundary(2) x_boundary(2) x_boundary(1) x_boundary(1)], ...
    [y_boundary(1) y_boundary(1) y_boundary(2) y_boundary(2) y_boundary(1)] ...
);


%% Let the user select the sound source
soundsources = fieldnames(artoaWorkspace.filteredSoundsources);

[index, success] = listdlg( ...
    'PromptString', 'Soundsources:',...
    'SelectionMode', 'single',...
    'ListString', soundsources ...
);

if ~success
    return;
end

%% Store 

% update sound source of selected points
artoaWorkspace.toaData.soundSource( ...
    selection ...
) = soundsources(index);

% apply status to selection
artoaWorkspace.toaData.status(selection) = 1;

%% Update duplicate toa table
artoa.controller.edit.timeOfArrival.updateDuplicateToaTable();

%% Update offsets table and recalculate TOAs
artoa.controller.edit.offsets.tableSoundsourceOffsetsEdit();

%% Update track parameter window if available
artoa.controller.track.parameter.updateGui();

%% Update plots
artoa.controller.edit.updateAvailablePlots();

end

