function [] = calculateGpsToas()
%CALCULATEGPSTOAS Calculates the SAT TOAs of all soundsources.
%   Calculates the SAT TOAs by artoa.toa.predictFromGps. Adds the
%   soundsource offset and drift if already selected.

global artoaWorkspace artoaDataInput;

%% Get all soundsources
fnames = fieldnames(artoaWorkspace.filteredSoundsources);

artoaWorkspace.editTimeOfArrival.satToa = struct();

%% Calculate GPS TOAs for every soundsource
for o = 1:length(fnames)
    % initialize data storage
    artoaWorkspace.editTimeOfArrival.satToa.(fnames{o}) = struct();
    % calculate rafos dates of soundsource
    soundSourceBegin = artoa.convert.dmy2rd(artoaDataInput.soundsources.(fnames{o}).begemis(3), ...
        artoaDataInput.soundsources.(fnames{o}).begemis(2), ...
        artoaDataInput.soundsources.(fnames{o}).begemis(1));
    soundSourceEnd = artoa.convert.dmy2rd(artoaDataInput.soundsources.(fnames{o}).endemis(3), ...
        artoaDataInput.soundsources.(fnames{o}).endemis(2), ...
        artoaDataInput.soundsources.(fnames{o}).endemis(1));

    [gpsDates, predictedToas] = artoa.toa.predictFromGps( ...
        artoaDataInput.rfb, artoaWorkspace.filteredSoundsources.(fnames{o}), ...
        struct( ...
            'temperature', artoaWorkspace.temperature(artoaWorkspace.statusTemperature == 1), ...
            'pressure', artoaWorkspace.pressure(artoaWorkspace.statusPressure == 1), ...
            'method', 'del grosso', ...
            'soundSource', NaN ...
        ), ...
        artoa.data.getMember(artoaDataInput, {'ini', 'leapseconds'}) ...
    );

    % add soundsource drift
    if artoa.data.hasMember(artoaWorkspace, {'editOffsets', 'offsets'}) ...
            && any(contains(artoaWorkspace.editOffsets.offsets.Properties.RowNames, fnames{o})) ...
            && artoaWorkspace.editOffsets.useOffsets
        offset = artoaWorkspace.editOffsets.offsets{fnames{o}, 'EmpiricalOffset'};
        drift = artoaWorkspace.editOffsets.offsets{fnames{o}, 'EmpiricalDrift'};
        % no sorting required, because fourth parameter contains timesteps
        predictedToas = artoa.toa.addDrift( ...
            predictedToas, ...
            offset, ...
            drift, ...
            floor(gpsDates - soundSourceBegin) ...
        );
    end

    % remove gps dates that are past end mission of sound source
    selection = (gpsDates > soundSourceEnd);
    gpsDates(selection) = NaN;
    predictedToas(selection) = NaN;
    % remove gps dates before deployment of soundsource
    selection = (gpsDates < soundSourceBegin);
    gpsDates(selection) = NaN;
    predictedToas(selection) = NaN;
    clear selection;
    
    % save to workspace
    artoaWorkspace.editTimeOfArrival.satToa.(fnames{o}).gpsDate = gpsDates;
    artoaWorkspace.editTimeOfArrival.satToa.(fnames{o}).gpsToa = predictedToas;
end


end

