function [] = pickPolygon()
%PICKPOLYGON Lets the user pick a polygon in the plot.
%   During selection, a line is being plotted that shows the selected
%   points by the user.
%   The polygon can be stopped by using the right mouse button. If
%   finished, the selected points are being calculated and stored in the
%   artoaWorkspace variable.

global artoaGui artoaWorkspace;

%% Check if polygon is already selected

artoa.controller.edit.timeOfArrival.dropSelection();

%% Select polygon by mouse
x = [];
y = [];

% draw the line that will be extended on every click
artoaGui.editTimeOfArrival.userSelection = line( ...
    NaN, NaN, 'Color', [0 0 0], 'LineStyle', '-' ...
);

[dx, dy, button] = ginput(1);
while button == 1
    % get boundaries
    bound = artoaGui.editTimeOfArrival.axesScatterTimeOfArrival.XLim;
    dx = artoa.data.adjustToBoundaries(dx, bound(1), bound(2));
    bound = artoaGui.editTimeOfArrival.axesScatterTimeOfArrival.YLim;
    dy = artoa.data.adjustToBoundaries(dy, bound(1), bound(2));
    % add values to array
    x = [x; dx];
    y = [y; dy];
    if length(x) == 1
        continue;
    end
    % update the line
    set(artoaGui.editTimeOfArrival.userSelection, 'XData', x, 'YData', y);
    [dx, dy, button] = ginput(1);
end

% close the poligon by adding the first value as the last one
if length(x) > 3 % a polygon can only be closed if there are more than three values
    x = [x; x(1)];
    y = [y; y(1)];
else
    [artoaGui.editTimeOfArrival, artoaWorkspace.editTimeOfArrival] = artoa.controller.edit.clearSelection(artoaGui.editTimeOfArrival, artoaWorkspace.editTimeOfArrival);
    return;
end
% update the line
set(artoaGui.editTimeOfArrival.userSelection, 'XData', x, 'YData', y);

% store the selected points in the workspace for editing
artoaWorkspace.editTimeOfArrival.userSelection = inpolygon( ...
    artoaWorkspace.toaData.toaDate, ...
    artoaWorkspace.toaData.toa, ...
    x, ...
    y ...
);



end

