function [] = plotSoundsourceDeploymentRecover(pSoundsources)
%PLOTSOUNDSOURCEDEPLOYMENTRECOVER Summary of this function goes here
%   Detailed explanation goes here

global artoaGui artoaWorkspace artoaDataInput;

%% Required data
unappliedSoundsourcesColor = [0 0 0];

%% Just update the colors if already plotted
if artoa.data.hasMember(artoaGui, {'editTimeOfArrival', 'textSoundsourceDeployments'}) ...
    && artoa.data.hasMember(artoaGui, {'editTimeOfArrival', 'lineSoundsourceDeployments'}) ...
    && artoa.data.hasMember(artoaGui, {'editTimeOfArrival', 'textSoundsourceRecovers'}) ...
    && artoa.data.hasMember(artoaGui, {'editTimeOfArrival', 'lineSoundsourceRecovers'})

    fnames = fieldnames(pSoundsources);
    for o = 1:length(fnames)
        % estimate the color to be used
        if artoa.soundsources.hasAppliedToa(fnames{o}, artoaWorkspace.toaData.soundSource)
            [colorIndex, artoaWorkspace.soundsourceColorRegister] = ...
                artoa.soundsources.colorregister.add(fnames{o}, artoaWorkspace.soundsourceColorRegister);
            soundsourceColor = artoaWorkspace.soundsourceColors(colorIndex, :);
        else
            soundsourceColor = unappliedSoundsourcesColor;
        end
        artoaGui.editTimeOfArrival.textSoundsourceDeployments.(fnames{o}).Color = soundsourceColor;
        artoaGui.editTimeOfArrival.lineSoundsourceDeployments.(fnames{o}).Color = soundsourceColor;
        artoaGui.editTimeOfArrival.textSoundsourceRecovers.(fnames{o}).Color = soundsourceColor;
        artoaGui.editTimeOfArrival.lineSoundsourceRecovers.(fnames{o}).Color = soundsourceColor;
    end

    return;
end

%% Initialize handles
artoaGui.editTimeOfArrival.textSoundsourceDeployments = struct();
artoaGui.editTimeOfArrival.lineSoundsourceDeployments = struct();
artoaGui.editTimeOfArrival.textSoundsourceRecovers = struct();
artoaGui.editTimeOfArrival.lineSoundsourceRecovers = struct();

%% Parameters
yMax = max(artoaGui.editTimeOfArrival.axesScatterTimeOfArrival.YLim);
yMin = min(artoaGui.editTimeOfArrival.axesScatterTimeOfArrival.YLim);

toaMax = max(artoaWorkspace.toaData.toaDate(artoaWorkspace.toaData.status ~= 2));
toaMin = min(artoaWorkspace.toaData.toaDate(artoaWorkspace.toaData.status ~= 2));
toaExtension = 10;

%% Now plot again

hold(artoaGui.editTimeOfArrival.axesToaFromGps, 'on');

fnames = fieldnames(pSoundsources);

for o = 1:length(fnames)
    % estimate the color to be used
    if artoa.soundsources.hasAppliedToa(fnames{o}, artoaWorkspace.toaData.soundSource)
        [colorIndex, artoaWorkspace.soundsourceColorRegister] = ...
            artoa.soundsources.colorregister.add(fnames{o}, artoaWorkspace.soundsourceColorRegister);
        soundsourceColor = artoaWorkspace.soundsourceColors(colorIndex, :);
    else
        soundsourceColor = unappliedSoundsourcesColor;
    end
    % skip sound source if it went out of the water before the float range, or
    % went in the water after the float range
    soundSourceBegin = artoa.convert.dmy2rd(artoaDataInput.soundsources.(fnames{o}).begemis(3), ...
        artoaDataInput.soundsources.(fnames{o}).begemis(2), ...
        artoaDataInput.soundsources.(fnames{o}).begemis(1));
    soundSourceEnd = artoa.convert.dmy2rd(artoaDataInput.soundsources.(fnames{o}).endemis(3), ...
        artoaDataInput.soundsources.(fnames{o}).endemis(2), ...
        artoaDataInput.soundsources.(fnames{o}).endemis(1));

    % deployment

    if (soundSourceBegin > toaMin - toaExtension) ...
            && (soundSourceBegin < toaMax + toaExtension)
        artoaGui.editTimeOfArrival.textSoundsourceDeployments.(fnames{o}) = text( ...
            artoaGui.editTimeOfArrival.axesToaFromGps, ...
            soundSourceBegin, yMin, ...
            ['<-- ', fnames{o}], ...
            'Color', soundsourceColor, ...
            'HorizontalAlignment', 'left', ...
            'VerticalAlignment', 'bottom', ...
            'FontName', 'Helvetica', ...
            'FontSize', 10, ...
            'FontWeight', 'demi', ...
            'Rotation', 90 ...
        );
        artoaGui.editTimeOfArrival.lineSoundsourceDeployments.(fnames{o}) = plot( ...
            artoaGui.figures.editTimeOfArrival.CurrentAxes, ...
            [soundSourceBegin soundSourceBegin], [yMax yMin], ...
            'color', soundsourceColor, ...
            'LineStyle', '--' ...
        );
    end
    % recovering
    if (soundSourceEnd > toaMin - toaExtension) ...
            && (soundSourceEnd < toaMax + toaExtension)
        artoaGui.editTimeOfArrival.textSoundsourceRecovers.(fnames{o}) = text( ...
            artoaGui.editTimeOfArrival.axesToaFromGps, ...
            soundSourceEnd, yMax, ...
            [fnames{o}, ' -->'], ...
            'Color', soundsourceColor, ...
            'HorizontalAlignment', 'right', ...
            'VerticalAlignment', 'bottom', ...
            'FontName', 'Helvetica', ...
            'FontSize', 10, ...
            'FontWeight', 'demi', ...
            'Rotation', 90 ...
        );
        artoaGui.editTimeOfArrival.lineSoundsourceRecovers.(fnames{o}) = plot( ...
            artoaGui.figures.editTimeOfArrival.CurrentAxes, ...
            [soundSourceEnd soundSourceEnd], [yMax yMin], ...
            'Color', soundsourceColor, ...
            'LineStyle', ':' ...
        );
    end
    
end

hold(artoaGui.editTimeOfArrival.axesToaFromGps, 'off');

end

