function [] = plotSoundsourceToaFromGps(pSoundsources)
%PLOTSOUNDSOURCETOAFROMGPS Plots the given sound sources to the edit time of arrival plot.
%   Is called by artoa.controller.edit.timeOfArrival.plot()
%   CANNOT BE USED ISOLATED.
%
%   Parameters:
%       pSoundsources (struct)  The soundsources that are to be used.

global artoaWorkspace artoaGui;

%% Initialize required variables
unappliedSoundsourcesColor = [0 0 0];

if isfield(artoaGui.editTimeOfArrival, 'axesToaFromGps') ...
        && isvalid(artoaGui.editTimeOfArrival.axesToaFromGps)
    
    fnames = fieldnames(pSoundsources);
    for o = 1:length(fnames)
        
        % get color
        if artoa.soundsources.hasAppliedToa(fnames{o}, artoaWorkspace.toaData.soundSource)
            [colorIndex, artoaWorkspace.soundsourceColorRegister] = ...
                artoa.soundsources.colorregister.add(fnames{o}, artoaWorkspace.soundsourceColorRegister);
            soundsourceColor = artoaWorkspace.soundsourceColors(colorIndex, :);
        else
            soundsourceColor = unappliedSoundsourcesColor;
        end
    
        % get values
        xData = artoaWorkspace.editTimeOfArrival.satToa.(fnames{o}).gpsDate;
        yData = artoaWorkspace.editTimeOfArrival.satToa.(fnames{o}).gpsToa;
        
        % update scatter
        artoaGui.editTimeOfArrival.scatterToaFromGps.(fnames{o}).MarkerEdgeColor = soundsourceColor;
        artoaGui.editTimeOfArrival.scatterToaFromGps.(fnames{o}).XData = xData';
        artoaGui.editTimeOfArrival.scatterToaFromGps.(fnames{o}).YData = yData';
        
        for t = 1:length(artoaGui.editTimeOfArrival.textToaFromGps.(fnames{o}))
            current = artoaGui.editTimeOfArrival.textToaFromGps.(fnames{o})(t);
            current.Color = soundsourceColor; % update text color
            if isnan(current.Position(1))
                continue;
            end
            xIndex = find(xData == current.Position(1));
            if xIndex >= 0 && ~isnan(xIndex)
                current.Position(2) = yData(xIndex);
            end
        end
        
    end
    return
end

artoaGui.editTimeOfArrival.axesToaFromGps = axes(artoaGui.figures.editTimeOfArrival);

artoaGui.editTimeOfArrival.scatterToaFromGps = struct();
artoaGui.editTimeOfArrival.textToaFromGps = struct();

hold(artoaGui.editTimeOfArrival.axesToaFromGps, 'on');

%% Collect required data
yMax = max(artoaGui.editTimeOfArrival.axesScatterTimeOfArrival.YLim);
yMin = min(artoaGui.editTimeOfArrival.axesScatterTimeOfArrival.YLim);

%% Create plot
fnames = fieldnames(pSoundsources);

for o = 1:length(fnames)
    % estimate the color to be used
    if artoa.soundsources.hasAppliedToa(fnames{o}, artoaWorkspace.toaData.soundSource)
        [colorIndex, artoaWorkspace.soundsourceColorRegister] = ...
            artoa.soundsources.colorregister.add(fnames{o}, artoaWorkspace.soundsourceColorRegister);
        soundsourceColor = artoaWorkspace.soundsourceColors(colorIndex, :);
    else
        soundsourceColor = unappliedSoundsourcesColor;
    end
        
    artoaGui.editTimeOfArrival.scatterToaFromGps.(fnames{o}) = scatter( ...
        artoaGui.editTimeOfArrival.axesToaFromGps, ...
        artoaWorkspace.editTimeOfArrival.satToa.(fnames{o}).gpsDate, ...
        artoaWorkspace.editTimeOfArrival.satToa.(fnames{o}).gpsToa, ...
        50, ...
        'MarkerEdgeColor', soundsourceColor ...
    );
    
    % use only every third gps date for text
    artoaGui.editTimeOfArrival.textToaFromGps.(fnames{o}) = text( ...
        artoaGui.editTimeOfArrival.axesToaFromGps, ...
        artoaWorkspace.editTimeOfArrival.satToa.(fnames{o}).gpsDate(1:3:end), ...
        artoaWorkspace.editTimeOfArrival.satToa.(fnames{o}).gpsToa(1:3:end), ...
        ['  ' fnames{o}], ...
        'HorizontalAlignment', 'left', ...
        'VerticalAlignment', 'top', ...
        'FontName', 'Helvetica', ...¬                                     
        'FontSize', 10, ...¬                                              
        'FontWeight', 'demi', ...¬                                        
        'Color', soundsourceColor ...%[1 1 1] ...
    );
end

hold(artoaGui.editTimeOfArrival.axesToaFromGps, 'off');


end

