function [boolean] = hasMember(pStructure, varargin)
%HASVARIABLE Checks the given structure if the member is available.
%   Checks if the fields are available in the given structure.
%   Example:
%       hasMember(S, 'hello', 'world')
%       checks if S.hello.world member is available.
%   Parameters:
%       pStructure (struct) The structure where the member will be
%                           searched for.
%       varargin (char)     Every additional char array represents the
%                           level of the structure.
%
%   Returns (bool) False if the member is not available.

%% Initialization
boolean = false;

%% Parameter check
if isempty(varargin)
    return;
end

if length(varargin) == 1 && iscell(varargin{1})
    varargin = varargin{1};
end

%% Check all levels
currentLevel = pStructure;
for i = 1:length(varargin)
    if isfield(currentLevel, varargin{i})
        currentLevel = currentLevel.(varargin{i});
    else
        return;
    end
end

boolean = true;

end

