function [] = temperature()
%TEMPERATURE Defines the ARTOA4 edit temperature window.

global artoaGui artoaWorkspace;

%% Initialize required variables

windowTitle = [ 'ARTOA4 - Float ' num2str(artoaWorkspace.float.floatname) ' - Temperature' ];


%% Initialize temperature gui

artoaGui.figures.editTemperature = figure( ...
    'Name', windowTitle, ...
    'NumberTitle', 'off' ...
);
addToolbarExplorationButtons(artoaGui.figures.editTemperature);

artoaGui.editTemperature = struct();

set( ...
    artoaGui.figures.editTemperature, ...
    'CloseRequestFcn', ...
    @artoa.controller.edit.temperature.close ...
);

%% Generate Plot

artoa.controller.edit.updateAvailablePlots();

set(gca, 'Position', [0.13 0.11 0.706 0.815]);

%% Generate Controls

left = .85;
width = .14;

%% PICK
pickButtonHeight = .25;

artoaGui.editTemperature.frameControlsPick = uipanel( ...
    'Title', 'Pick', ...
    'Units', 'normalized', ...
    'BackgroundColor', 'white', ...
    'Position', [left .72 width .2] ...
);

artoaGui.editTemperature.buttonPickPolygon = uicontrol( ...
    'Parent', artoaGui.editTemperature.frameControlsPick, ...
    'String', 'Polygon', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .65 .69 pickButtonHeight], ...
    'CallBack', 'artoa.controller.edit.temperature.pickPolygon();' ...
);

artoaGui.editTemperature.buttonPickPoint = uicontrol( ...
    'Parent', artoaGui.editTemperature.frameControlsPick, ...
    'String', 'Point', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .35 .69 pickButtonHeight], ...
    'CallBack', 'artoa.controller.edit.temperature.pickPoint();' ...
);

artoaGui.editTemperature.buttonDropSelection = uicontrol( ...
    'Parent', artoaGui.editTemperature.frameControlsPick, ...
    'String', 'Drop', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .05 .69 pickButtonHeight], ...
    'CallBack', 'artoa.controller.edit.temperature.dropSelection();' ...
);

%% APPLY
applyButtonHeight = .25;

artoaGui.editTemperature.frameControlsApply = uipanel( ...
    'Title', 'Apply', ...
    'Units', 'normalized', ...
    'BackgroundColor', 'white', ...
    'Position', [left .5 width .2] ...
);

artoaGui.editTemperature.buttonApply = uicontrol( ...
    'Parent', artoaGui.editTemperature.frameControlsApply, ...
    'String', 'Selected', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .65 .69 applyButtonHeight], ...
    'CallBack', 'artoa.controller.edit.temperature.applyStatusToSelectedPoints(1);' ...
);

artoaGui.editTemperature.buttonApplyAllVisible = uicontrol( ...
    'Parent', artoaGui.editTemperature.frameControlsApply, ...
    'String', 'All visible', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .35 .69 applyButtonHeight], ...
    'CallBack', 'artoa.controller.edit.temperature.applyStatusToAllVisible(1);' ...
);

artoaGui.editTemperature.buttonApplyAll = uicontrol( ...
    'Parent', artoaGui.editTemperature.frameControlsApply, ...
    'String', 'All', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .05 .69 applyButtonHeight], ...
    'CallBack', 'artoa.controller.edit.temperature.applyStatusToAllPoints(1);' ...
);

%% RESET
resetButtonHeight = .25;

artoaGui.editTemperature.frameControlsReset = uipanel( ...
    'Title', 'Reset', ...
    'Units', 'normalized', ...
    'BackgroundColor', 'white', ...
    'Position', [left .28 width .2] ...
);

artoaGui.editTemperature.buttonReset = uicontrol( ...
    'Parent', artoaGui.editTemperature.frameControlsReset, ...
    'String', 'Selected', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .65 .69 resetButtonHeight], ...
    'CallBack', 'artoa.controller.edit.temperature.applyStatusToSelectedPoints(0);' ...
);

artoaGui.editTemperature.buttonResetAllVisible = uicontrol( ...
    'Parent', artoaGui.editTemperature.frameControlsReset, ...
    'String', 'All visible', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .35 .69 resetButtonHeight], ...
    'CallBack', 'artoa.controller.edit.temperature.applyStatusToAllVisible(0);' ...
);

artoaGui.editTemperature.buttonResetAll = uicontrol( ...
    'Parent', artoaGui.editTemperature.frameControlsReset, ...
    'String', 'All', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .05 .69 resetButtonHeight], ...
    'CallBack', 'artoa.controller.edit.temperature.applyStatusToAllPoints(0);' ...
);

%% DELETE
deleteButtonHeight = .4;

artoaGui.editTemperature.frameControlsDelete = uipanel( ...
    'Title', 'Delete', ...
    'Units', 'normalized', ...
    'BackgroundColor', 'white', ...
    'Position', [left .11 width .15] ...
);

artoaGui.editTemperature.buttonDelete = uicontrol( ...
    'Parent', artoaGui.editTemperature.frameControlsDelete, ...
    'String', 'Selected', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .3 .69 deleteButtonHeight], ...
    'CallBack', 'artoa.controller.edit.temperature.applyStatusToSelectedPoints(2);' ...
);

%% Enable zoom
zoom on;

end

