function [] = parameter(pCallbacks, pTrackingMethods, pInterpolationMethods, pSoundspeedMethods)
%PARAMETER Defines the ARTOA4 tracking parameter window.

global artoaGui artoaWorkspace;

%% Initialize required variables

windowTitle = [ 'ARTOA4 - Float ' num2str(artoaWorkspace.float.floatname) ' - Tracking Parameter' ];

availableCallbacks = { ...
    'CloseRequestFcn', ...
    'comboboxTrackingMethod', ...
    'checkboxDopplerCorrection', ...
    'comboboxInterpolationMethod', ...
    'comboboxSoundspeedMethod', ...
    'checkboxPlotResiduals', ...
    'inputOutputInterpolationInterval', ...
    'inputGapSize', ...
    'tableSoundSourceCombinationsSelection', ...
    'tableSoundSourceCombinationsEdit', ...
    'buttonTrack', ...
    'buttonAddCombination', ...
    'buttonAddCombinationAbove', ...
    'buttonDuplicateCombination', ...
    'buttonRemoveCombination', ...
    'buttonResetAllCombinations' ...
};

for i = 1:length(availableCallbacks) % check if a callback is undefined
    if ~isfield(pCallbacks, availableCallbacks{i})
        pCallbacks.(availableCallbacks{i}) = @(~, ~) false;
    end
end


%% Initialize track parameter gui

artoaGui.figures.trackParameter = figure( ...
    'Name', windowTitle, ...
    'NumberTitle', 'off', ...
    'MenuBar','none', ...
    'Units', 'characters', ...
    'Position', [3, 5, 129, 30] ...
);

artoaGui.trackParameter = struct();

set( ...
    artoaGui.figures.trackParameter, ...
    'CloseRequestFcn', ...
    pCallbacks.CloseRequestFcn ...
);

%% Controls defaults

left = .025;
width = .20;
buttonHeight = .3;

%% Tracking method frame

artoaGui.trackParameter.frameTrackingMethod = uipanel( ...
    'Title', 'Tracking Method', ...
    'Units', 'normalized', ...
    'BackgroundColor', 'white', ...
    'Position', [left .75 width .20] ...
);

artoaGui.trackParameter.comboboxTrackingMethod = uicontrol( ...
    'Parent', artoaGui.trackParameter.frameTrackingMethod, ...
    'String', pTrackingMethods, ...
    'Style', 'popupmenu', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [left .5 .9 .4], ...
    'CallBack', pCallbacks.comboboxTrackingMethod ...
);

artoaGui.trackParameter.checkboxDopplerCorrection = uicontrol( ...
    'Parent', artoaGui.trackParameter.frameTrackingMethod, ...
    'String', 'Apply Doppler Correction', ...
    'Style', 'checkbox', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [left .1 .9 .3], ...
    'Value', 1, ...
    'CallBack', pCallbacks.checkboxDopplerCorrection ...
);

%% Interpolation method frame
artoaGui.trackParameter.frameInterpolationMethod = uipanel( ...
    'Title', 'Input Interpolation Method', ...
    'Units', 'normalized', ...
    'BackgroundColor', 'white', ...
    'Position', [(2*left + width) .75 width .20] ...
);

artoaGui.trackParameter.comboboxInterpolationMethod = uicontrol( ...
    'Parent', artoaGui.trackParameter.frameInterpolationMethod, ...
    'String', pInterpolationMethods, ...
    'Style', 'popupmenu', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [left .5 .9 .4], ...
    'CallBack', pCallbacks.comboboxInterpolationMethod ...
);
clear methods;

artoaGui.trackParameter.textGapSize = uicontrol( ...
    'Parent', artoaGui.trackParameter.frameInterpolationMethod, ...
    'String', 'Gap Size [days]', ...
    'Style', 'text', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [left .1 .5 .3], ...
    'CallBack', '' ...
);

artoaGui.trackParameter.inputGapSize = uicontrol( ...
    'Parent', artoaGui.trackParameter.frameInterpolationMethod, ...
    'String', '10', ...
    'Style', 'edit', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [(.7-left) .1 .3 .3], ...
    'CallBack', pCallbacks.inputGapSize ...
);

%% Soundspeed method frame

artoaGui.trackParameter.frameSoundspeedMethod = uipanel( ...
    'Title', 'Sound Speed Method', ...
    'Units', 'normalized', ...
    'BackgroundColor', 'white', ...
    'Position', [(3*left + 2*width) .75 width .20] ...
);

artoaGui.trackParameter.comboboxSoundspeedMethod = uicontrol( ...
    'Parent', artoaGui.trackParameter.frameSoundspeedMethod, ...
    'String', pSoundspeedMethods, ...
    'Style', 'popupmenu', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [left .5 .9 .4], ...
    'CallBack', pCallbacks.comboboxSoundspeedMethod ...
);

artoaGui.trackParameter.checkboxPlotResiduals = uicontrol( ...
    'Parent', artoaGui.trackParameter.frameSoundspeedMethod, ...
    'String', 'Plot Residuals', ...
    'Enable', 'off', ...
    'Style', 'checkbox', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [left .1 .9 .3], ...
    'CallBack', pCallbacks.checkboxPlotResiduals ...
);

%% Output interpolation interval
artoaGui.trackParameter.textOutputInterpolationInterval = uicontrol( ...
    'Parent', artoaGui.figures.trackParameter, ...
    'String', 'Output Interpolation Interval [h]', ...
    'Style', 'text', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [(4*left + 3*width) .75 (.5*width) .20], ...
    'CallBack', '' ...
);

artoaGui.trackParameter.inputOutputInterpolationInterval = uicontrol( ...
    'Parent', artoaGui.figures.trackParameter, ...
    'String', '24', ...
    'Style', 'edit', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [(5*left + 3*width) .775 (.25*width) .05], ...
    'CallBack', pCallbacks.inputOutputInterpolationInterval ...
);

%% Sound source combination table

columns = { ...
    'Begin', ...
    'End', ...
    'Sound Sources', ...
    'Reference Position', ...
    'Sound Speed', 'Sound Speed', 'Sound Speed' ...
};
artoaGui.trackParameter.tableSoundSourceCombinations = uitable( ...
    artoaGui.figures.trackParameter, ...
    'Units', 'normalized', ...
    'Position', [left, 0.05, (5*left + 3.25*width), 0.65], ...
    'Data', cell(1, length(columns)), ...
    'ColumnName', columns, ...
    'ColumnEditable', true, ...
    'CellSelectionCallback', pCallbacks.tableSoundSourceCombinationsSelection,... %@(app,event) disp(num2str(event.Indices)) ...
    'CellEditCallback', pCallbacks.tableSoundSourceCombinationsEdit ...
);
clear columns;

%% Track buttons frame

artoaGui.trackParameter.frameTrackButtons = uipanel( ...
    'Title', 'Tracking controls', ...
    'Units', 'normalized', ...
    'BackgroundColor', 'white', ...
    'Position', [(1-left-.75*width) .58 .75*width .20] ...
);

artoaGui.trackParameter.buttonTrack = uicontrol( ...
    'Parent', artoaGui.trackParameter.frameTrackButtons, ...
    'String', 'Track', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [left .3 (1-2*left) buttonHeight], ...
    'CallBack', pCallbacks.buttonTrack ...
);

%% Combination buttons frame

artoaGui.trackParameter.frameCombinationButtons = uipanel( ...
    'Title', 'Combination controls', ...
    'Units', 'normalized', ...
    'BackgroundColor', 'white', ...
    'Position', [(1-left-.75*width) .13 .75*width .40] ...
);

artoaGui.trackParameter.buttonAddCombination = uicontrol( ...
    'Parent', artoaGui.trackParameter.frameCombinationButtons, ...
    'String', 'Add', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [left .8 (1-2*left) .4*buttonHeight], ...
    'CallBack', pCallbacks.buttonAddCombination ...
);

artoaGui.trackParameter.buttonAddAboveCombination = uicontrol( ...
    'Parent', artoaGui.trackParameter.frameCombinationButtons, ...
    'String', 'Add above selected', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [left .65 (1-2*left) .4*buttonHeight], ...
    'CallBack', pCallbacks.buttonAddCombinationAbove ...
);

artoaGui.trackParameter.buttonDuplicateCombination = uicontrol( ...
    'Parent', artoaGui.trackParameter.frameCombinationButtons, ...
    'String', 'Duplicate selected', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [left .5 (1-2*left) .4*buttonHeight], ...
    'CallBack', pCallbacks.buttonDuplicateCombination ...
);


artoaGui.trackParameter.buttonRemoveCombination = uicontrol( ...
    'Parent', artoaGui.trackParameter.frameCombinationButtons, ...
    'String', 'Remove selected', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [left .35 (1-2*left) .4*buttonHeight], ...
    'CallBack', pCallbacks.buttonRemoveCombination ...
);

artoaGui.trackParameter.buttonResetAllCombinations = uicontrol( ...
    'Parent', artoaGui.trackParameter.frameCombinationButtons, ...
    'String', 'Reset All', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [left .1 (1-2*left) .4*buttonHeight], ...
    'CallBack', pCallbacks.buttonResetAllCombinations ...
);

end

