function [filteredSoundsources] = filter(pSoundsources, pBeginDate, pEndDate)
%FILTER Returns only the sound sources that fit the boundaries.
%   Checks if the soundsource is alive between the given begin and end
%   date. Returns only the ones that pass the test.
%
%   Parameters:
%       pSoundsources (struct)    Each cell contains a sound source struct.
%       pBeginDate (double)     The begin date in rafos format.
%       pEndDate (double)     The end date in rafos format.
%
%   Returns:
%       filteredSoundsources (struct)     The filtered soundsource cell.

filteredSoundsources = struct();

fnames = fieldnames(pSoundsources);

for o = 1:length(fnames)
    soundSourceBegin = artoa.convert.dmy2rd(pSoundsources.(fnames{o}).begemis(3), ...
        pSoundsources.(fnames{o}).begemis(2), ...
        pSoundsources.(fnames{o}).begemis(1));
    soundSourceEnd = artoa.convert.dmy2rd(pSoundsources.(fnames{o}).endemis(3), ...
        pSoundsources.(fnames{o}).endemis(2), ...
        pSoundsources.(fnames{o}).endemis(1)); 
    if soundSourceEnd < pBeginDate ...
        || soundSourceBegin > pEndDate
        continue;
    end
    filteredSoundsources.(fnames{o}) = pSoundsources.(fnames{o});
end

end

